@@ -4,15 +4,19 @@ import shutil
 from . import helper
 from .code_organizer import CodeOrganizer
 from .ext_exception import ExtException
+from datetime import datetime
 
 
 class FileOrganizer:
 
     @classmethod
     def unpack(cls, src_dir, dest_dir, *, pool=None, index=None, descent=None):
+        begin = datetime.now()
+        print(f'{"Организуем код":30}')
         tasks = []
         cls._unpack(src_dir, os.path.abspath(dest_dir), '', tasks, index, descent)
-        helper.run_in_pool(cls.unpack_code_file, tasks, pool=pool)
+        helper.run_in_pool(cls.unpack_code_file, tasks, pool=pool, title=f'{"Раскладываем код по файлам":30}')
+        print(f'{"Организуем код - готово":30}: {datetime.now() - begin}')
 
     @classmethod
     def _unpack(cls, src_dir, dest_dir, path, tasks, index, descent=None):
@@ -37,7 +41,7 @@ class FileOrganizer:
         dest_full_path = os.path.abspath(os.path.join(dest_dir, dest_entry_path))
 
         if dest_entry_path:
-            os.makedirs(dest_full_path, exist_ok=True)
+            helper.makedirs(dest_full_path, exist_ok=True)
 
         src_full_path = os.path.join(src_path, src_file_name)
 
@@ -53,9 +57,10 @@ class FileOrganizer:
             shutil.copy(src_full_path, os.path.join(descent_full_dest_path, descent_file_name))
 
     @classmethod
-    def unpack_code_file(cls, src_dir, path, file_name, dest_dir, index, descent=None):
+    def unpack_code_file(cls, params):
+        src_dir, path, file_name, dest_dir, index, descent = params
         try:
-            code_areas = CodeOrganizer.unpack(src_dir, path, file_name, dest_dir, index)
+            code_areas = CodeOrganizer.unpack(params)
             for elem in code_areas:
                 _file = code_areas[elem]
                 if elem == 'root':
@@ -73,7 +78,6 @@ class FileOrganizer:
                     descent_full_dest_path, descent_file_name = _file['dest_path'], _file['file_name']
 
                 if descent_file_name:
-                    os.makedirs(descent_full_dest_path, exist_ok=True)
                     helper.txt_write(_file['data'], descent_full_dest_path, descent_file_name)
         except Exception as err:
             raise ExtException(
@@ -106,6 +110,8 @@ class FileOrganizer:
 
     @classmethod
     def pack(cls, src_dir, dest_dir, *, pool=None, index=None, descent=None):
+        begin = datetime.now()
+        print(f'{"Собираем код":30}')
         helper.clear_dir(dest_dir)
         tasks = []
         src_dir = os.path.abspath(src_dir)
@@ -113,7 +119,8 @@ class FileOrganizer:
         if index:
             cls._pack_index(src_dir, dest_dir, tasks, index, index_code_areas, [''], descent)
         cls._pack(src_dir, dest_dir, '', tasks, index, index_code_areas, descent)
-        helper.run_in_pool(CodeOrganizer.pack, tasks, pool=pool)
+        helper.run_in_pool(CodeOrganizer.pack, tasks, pool=pool, title=f'{"Собираем код из файлов":30}')
+        print(f'{"Собираем код - готово":30}: {datetime.now() - begin}')
 
     @classmethod
     def _pack_index(cls, src_dir: str, dest_dir: str, tasks: list, index: dict, index_code_areas: dict, path: list,
@@ -171,7 +178,7 @@ class FileOrganizer:
     @classmethod
     def _pack(cls, src_dir, dest_dir, path, tasks, index, index_code_areas, descent=None):
         if path:
-            os.makedirs(os.path.join(dest_dir, path), exist_ok=True)
+            helper.makedirs(os.path.join(dest_dir, path), exist_ok=True)
         entries = cls.list_descent_dir(src_dir, path, descent)
         for entry in entries:
             try:
@@ -203,5 +210,5 @@ class FileOrganizer:
             shutil.copy(_src_path, _dest_path)
         except FileNotFoundError:
             _dest_dir = os.path.dirname(_dest_path)
-            os.makedirs(_dest_dir, exist_ok=True)
+            helper.makedirs(_dest_dir, exist_ok=True)
             shutil.copy(_src_path, _dest_path)
